summaryrefslogtreecommitdiffstats
path: root/kjsembed/qtbindings/qmenuitem_imp.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kjsembed/qtbindings/qmenuitem_imp.cpp')
-rw-r--r--kjsembed/qtbindings/qmenuitem_imp.cpp108
1 files changed, 54 insertions, 54 deletions
diff --git a/kjsembed/qtbindings/qmenuitem_imp.cpp b/kjsembed/qtbindings/qmenuitem_imp.cpp
index c2be558c..75118e4e 100644
--- a/kjsembed/qtbindings/qmenuitem_imp.cpp
+++ b/kjsembed/qtbindings/qmenuitem_imp.cpp
@@ -23,19 +23,19 @@
*/
namespace KJSEmbed {
-QMenuItemImp::QMenuItemImp( KJS::ExecState *exec, int mid, bool constructor )
+TTQMenuItemImp::TQMenuItemImp( KJS::ExecState *exec, int mid, bool constructor )
: JSProxyImp(exec), id(mid), cons(constructor)
{
}
-QMenuItemImp::~QMenuItemImp()
+TTQMenuItemImp::~TQMenuItemImp()
{
}
/**
* Adds bindings for static methods and enum constants to the specified Object.
*/
-void QMenuItemImp::addStaticBindings( KJS::ExecState *exec, KJS::Object &object )
+void TQMenuItemImp::addStaticBindings( KJS::ExecState *exec, KJS::Object &object )
{
JSProxy::MethodTable methods[] = {
@@ -43,11 +43,11 @@ void QMenuItemImp::addStaticBindings( KJS::ExecState *exec, KJS::Object &object
};
int idx = 0;
- TQCString lastName;
+ TTQCString lastName;
while( methods[idx].name ) {
if ( lastName != methods[idx].name ) {
- QMenuItemImp *meth = new QMenuItemImp( exec, methods[idx].id );
+ TQMenuItemImp *meth = new TQMenuItemImp( exec, methods[idx].id );
object.put( exec , methods[idx].name, KJS::Object(meth) );
lastName = methods[idx].name;
}
@@ -60,7 +60,7 @@ void QMenuItemImp::addStaticBindings( KJS::ExecState *exec, KJS::Object &object
/**
* Adds bindings for instance methods to the specified Object.
*/
-void QMenuItemImp::addBindings( KJS::ExecState *exec, KJS::Object &object )
+void TQMenuItemImp::addBindings( KJS::ExecState *exec, KJS::Object &object )
{
JSProxy::MethodTable methods[] = {
{ Method_id_3, "id" },
@@ -86,29 +86,29 @@ void QMenuItemImp::addBindings( KJS::ExecState *exec, KJS::Object &object )
{ 0, 0 }
};
- JSProxy::addMethods<QMenuItemImp>(exec, methods, object );
+ JSProxy::addMethods<TQMenuItemImp>(exec, methods, object );
}
/**
* Extract a TQMenuItem pointer from an Object.
*/
-TQMenuItem *QMenuItemImp::toQMenuItem( KJS::Object &self )
+TTQMenuItem *TQMenuItemImp::toTQMenuItem( KJS::Object &self )
{
JSObjectProxy *ob = JSProxy::toObjectProxy( self.imp() );
if ( ob ) {
- TQObject *obj = ob->object();
+ TTQObject *obj = ob->object();
if ( obj )
- return dynamic_cast<TQMenuItem *>( obj );
+ return dynamic_cast<TTQMenuItem *>( obj );
}
- if( !JSProxy::checkType(self, JSProxy::ObjectProxy, "TQMenuItem") ) {
- TQObject *obj = JSProxy::toObjectProxy( self.imp() )->object();
- return dynamic_cast<TQMenuItem *>( obj );
+ if( !JSProxy::checkType(self, JSProxy::ObjectProxy, "TTQMenuItem") ) {
+ TTQObject *obj = JSProxy::toObjectProxy( self.imp() )->object();
+ return dynamic_cast<TTQMenuItem *>( obj );
}
- if( !JSProxy::checkType(self, JSProxy::OpaqueProxy, "TQMenuItem") ) {
- return JSProxy::toOpaqueProxy( self.imp() )->toNative<TQMenuItem>();
+ if( !JSProxy::checkType(self, JSProxy::OpaqueProxy, "TTQMenuItem") ) {
+ return JSProxy::toOpaqueProxy( self.imp() )->toNative<TTQMenuItem>();
}
return 0;
@@ -117,38 +117,38 @@ TQMenuItem *QMenuItemImp::toQMenuItem( KJS::Object &self )
/**
* Select and invoke the correct constructor.
*/
-KJS::Object QMenuItemImp::construct( KJS::ExecState *exec, const KJS::List &args )
+KJS::Object TQMenuItemImp::construct( KJS::ExecState *exec, const KJS::List &args )
{
switch( id ) {
case Constructor_QMenuItem_1:
- return QMenuItem_1( exec, args );
+ return TQMenuItem_1( exec, args );
break;
default:
break;
}
- TQString msg = i18n("QMenuItemCons has no constructor with id '%1'").arg(id);
+ TTQString msg = i18n("TQMenuItemCons has no constructor with id '%1'").arg(id);
return throwError(exec, msg,KJS::ReferenceError);
}
-KJS::Object QMenuItemImp::QMenuItem_1( KJS::ExecState *exec, const KJS::List &args )
+KJS::Object TQMenuItemImp::TQMenuItem_1( KJS::ExecState *exec, const KJS::List &args )
{
- // We should now create an instance of the TQMenuItem object
+ // We should now create an instance of the TTQMenuItem object
- TQMenuItem *ret = new TQMenuItem(
+ TTQMenuItem *ret = new TTQMenuItem(
);
return KJS::Object();
}
-KJS::Value QMenuItemImp::call( KJS::ExecState *exec, KJS::Object &self, const KJS::List &args )
+KJS::Value TQMenuItemImp::call( KJS::ExecState *exec, KJS::Object &self, const KJS::List &args )
{
- instance = QMenuItemImp::toQMenuItem( self );
+ instance = TQMenuItemImp::toTQMenuItem( self );
switch( id ) {
@@ -236,12 +236,12 @@ KJS::Value QMenuItemImp::call( KJS::ExecState *exec, KJS::Object &self, const KJ
break;
}
- TQString msg = i18n( "QMenuItemImp has no method with id '%1'" ).arg( id );
+ TTQString msg = i18n( "TQMenuItemImp has no method with id '%1'" ).arg( id );
return throwError(exec, msg,KJS::ReferenceError);
}
-KJS::Value QMenuItemImp::id_3( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
+KJS::Value TQMenuItemImp::id_3( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
int ret;
@@ -250,79 +250,79 @@ KJS::Value QMenuItemImp::id_3( KJS::ExecState *exec, KJS::Object &obj, const KJS
}
-KJS::Value QMenuItemImp::iconSet_4( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
+KJS::Value TQMenuItemImp::iconSet_4( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
instance->iconSet( );
- return KJS::Value(); // Returns 'TQIconSet *'
+ return KJS::Value(); // Returns 'TTQIconSet *'
}
-KJS::Value QMenuItemImp::text_5( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
+KJS::Value TQMenuItemImp::text_5( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- TQString ret;
+ TTQString ret;
ret = instance->text( );
return KJS::String( ret );
}
-KJS::Value QMenuItemImp::whatsThis_6( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
+KJS::Value TQMenuItemImp::whatsThis_6( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- TQString ret;
+ TTQString ret;
ret = instance->whatsThis( );
return KJS::String( ret );
}
-KJS::Value QMenuItemImp::pixmap_7( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
+KJS::Value TQMenuItemImp::pixmap_7( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
return convertToValue(exec, *instance->pixmap( ));
}
-KJS::Value QMenuItemImp::popup_8( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
+KJS::Value TQMenuItemImp::popup_8( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
instance->popup( );
- return KJS::Value(); // Returns 'TQPopupMenu *'
+ return KJS::Value(); // Returns 'TTQPopupMenu *'
}
-KJS::Value QMenuItemImp::widget_9( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
+KJS::Value TQMenuItemImp::widget_9( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
instance->widget( );
- return KJS::Value(); // Returns 'TQWidget *'
+ return KJS::Value(); // Returns 'TTQWidget *'
}
-KJS::Value QMenuItemImp::custom_10( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
+KJS::Value TQMenuItemImp::custom_10( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
instance->custom( );
- return KJS::Value(); // Returns 'TQCustomMenuItem *'
+ return KJS::Value(); // Returns 'TTQCustomMenuItem *'
}
-KJS::Value QMenuItemImp::key_11( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
+KJS::Value TQMenuItemImp::key_11( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
return convertToValue( exec, instance->key( ));
}
-KJS::Value QMenuItemImp::signal_12( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
+KJS::Value TQMenuItemImp::signal_12( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
instance->signal( );
- return KJS::Value(); // Returns 'TQSignal *'
+ return KJS::Value(); // Returns 'TTQSignal *'
}
-KJS::Value QMenuItemImp::isSeparator_13( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
+KJS::Value TQMenuItemImp::isSeparator_13( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
bool ret;
@@ -331,7 +331,7 @@ KJS::Value QMenuItemImp::isSeparator_13( KJS::ExecState *exec, KJS::Object &obj,
}
-KJS::Value QMenuItemImp::isEnabled_14( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
+KJS::Value TQMenuItemImp::isEnabled_14( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
bool ret;
@@ -340,7 +340,7 @@ KJS::Value QMenuItemImp::isEnabled_14( KJS::ExecState *exec, KJS::Object &obj, c
}
-KJS::Value QMenuItemImp::isChecked_15( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
+KJS::Value TQMenuItemImp::isChecked_15( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
bool ret;
@@ -349,7 +349,7 @@ KJS::Value QMenuItemImp::isChecked_15( KJS::ExecState *exec, KJS::Object &obj, c
}
-KJS::Value QMenuItemImp::isDirty_16( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
+KJS::Value TQMenuItemImp::isDirty_16( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
bool ret;
@@ -358,7 +358,7 @@ KJS::Value QMenuItemImp::isDirty_16( KJS::ExecState *exec, KJS::Object &obj, con
}
-KJS::Value QMenuItemImp::isVisible_17( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
+KJS::Value TQMenuItemImp::isVisible_17( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
bool ret;
@@ -367,7 +367,7 @@ KJS::Value QMenuItemImp::isVisible_17( KJS::ExecState *exec, KJS::Object &obj, c
}
-KJS::Value QMenuItemImp::isEnabledAndVisible_18( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
+KJS::Value TQMenuItemImp::isEnabledAndVisible_18( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
bool ret;
@@ -376,10 +376,10 @@ KJS::Value QMenuItemImp::isEnabledAndVisible_18( KJS::ExecState *exec, KJS::Obje
}
-KJS::Value QMenuItemImp::setText_19( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
+KJS::Value TQMenuItemImp::setText_19( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- TQString arg0 = extractQString(exec, args, 0);
+ TTQString arg0 = extractTQString(exec, args, 0);
instance->setText(
arg0 );
@@ -387,7 +387,7 @@ KJS::Value QMenuItemImp::setText_19( KJS::ExecState *exec, KJS::Object &obj, con
}
-KJS::Value QMenuItemImp::setDirty_20( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
+KJS::Value TQMenuItemImp::setDirty_20( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
bool arg0 = extractBool(exec, args, 0);
@@ -398,7 +398,7 @@ KJS::Value QMenuItemImp::setDirty_20( KJS::ExecState *exec, KJS::Object &obj, co
}
-KJS::Value QMenuItemImp::setVisible_21( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
+KJS::Value TQMenuItemImp::setVisible_21( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
bool arg0 = extractBool(exec, args, 0);
@@ -409,10 +409,10 @@ KJS::Value QMenuItemImp::setVisible_21( KJS::ExecState *exec, KJS::Object &obj,
}
-KJS::Value QMenuItemImp::setWhatsThis_22( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
+KJS::Value TQMenuItemImp::setWhatsThis_22( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- TQString arg0 = extractQString(exec, args, 0);
+ TTQString arg0 = extractTQString(exec, args, 0);
instance->setWhatsThis(
arg0 );
@@ -86,29 +86,29 @@ void QMenuItemImp::addBindings( KJS::ExecState *exec, KJS::Object &object )
}
/**
- * Extract a TQMenuItem pointer from an Object.
+ * Extract a TTQMenuItem pointer from an Object.
*/